#
# spec file for package python-django-timezone-field
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-django-timezone-field
Version:        7.0
Release:        1.1
Summary:        Django app providing database and form fields for pytz timezone objects
License:        BSD-2-Clause
Group:          Development/Languages/Python
URL:            https://github.com/mfogel/django-timezone-field/
Source:         https://github.com/mfogel/django-timezone-field/archive/%{version}.tar.gz#/django-timezone-field-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 2.3
Recommends:     python-pytz
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Django >= 2.3}
BuildRequires:  %{python_module djangorestframework}
BuildRequires:  %{python_module pytest-django}
BuildRequires:  %{python_module pytest-lazy-fixture}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pytz}
# /SECTION
%python_subpackages

%description
A Django app providing database and form fields for pytz timezone objects.

%prep
%setup -q -n django-timezone-field-%{version}
sed -Ei 's/_(TZChoicesDisplayModel|ZIChoicesDisplayModel)/\1/g' tests/test_choices_display_option.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export PYTHONPATH=${PWD}
export DJANGO_SETTINGS_MODULE=tests.settings
export TEST_DB_ENGINE=sqlite
%pytest

%files %{python_files}
%license LICENSE.txt
%doc README.md
%{python_sitelib}/timezone_field
%{python_sitelib}/django[-_]timezone[-_]field*/

%changelog
* Fri Jul 19 2024 Markéta Machová <mmachova@suse.com>
- Update to 7.0
  * Better default sorting of choices
  * Convert string value to timezone object immediately on creation/assignment
  * Add support for django 5.1
  * Drop support for django 3.2, 4.0, 4.1
  * Change base class of TimeZoneSerializerField from DJRF's Field to CharField
- Add missing test requirement and recommend pytz
* Tue Dec  5 2023 Dirk Müller <dmueller@suse.com>
- update to 6.1.0:
  * Add support for django 5.0
  * Add support for python 3.12
  * Fix issue with Factory timezone on some BSD systems (#114)
  * Use correct default backend when running with django 3.X (#109)
  * BREAKING: pytz removed from dependencies. If you use this package
    with use_pytz=True, you'll need to install pytz yourself.
  * Drop support for django 2.2
  * Drop support for python 3.7
* Sun Jun 25 2023 Dirk Müller <dmueller@suse.com>
- update to 5.1:
  - Add django as a dependency of this package, with correct version constraints
  - Add support for django 4.1, 4.2
  - Add support for python 3.11
* Tue Oct 11 2022 John Vandenberg <jayvdb@gmail.com>
- Update to v5.0
  * Add support for zoneinfo objects
  * Add support for django 4.0
  * Remove timezone_field.utils.add_gmt_offset_to_choices,
    display_GMT_offset kwarg (use choices_display instead)
  * Drop support for django 3.0, 3.1
  * Drop support for python 3.5, 3.6
- from v4.2.3
  * Fix sdist installs
  * Officially support python 3.10
- from v4.2.1
  * Reinstate TimeZoneField.default_choices (#76)
- from v4.2
  * Officially support django 3.2, python 3.9
  * Fix bug with field deconstruction
  * Housekeeping: use poetry, github actions, pytest
* Mon May 10 2021 Daniel Molkentin <daniel.molkentin@suse.com>
- Update to to 4.1.2
  * Avoid NonExistentTimeError during DST transition (#70)
  * Don't import rest_framework from package root (#67)
  * Add Django REST Framework serializer field
  * Add new choices_display kwarg with supported values WITH_GMT_OFFSET and STANDARD
  * Deprecate display_GMT_offset kwarg
* Wed Nov 18 2020 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
* Tue May 26 2020 ecsos <ecsos@opensuse.org>
- Define skip_python2 because not compatible to python 2.7.
- Run spec-cleaner.
* Fri Jan 17 2020 ecsos@opensuse.org
- Update to 4.0
  No changelog from upstream.
* Wed Mar  6 2019 Daniel Molkentin <daniel.molkentin@suse.com>
- Updated to 3.0
  No changelog provided
* Wed Feb  7 2018 daniel.molkentin@suse.com
- Initial checkin
